.. dj-bootstrap-components documentation master file, created by
   sphinx-quickstart on Sat May 16 01:18:19 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dj-bootstrap-components's documentation!
===================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Installing <installing>
   Getting Started <getting_started>
   Components <components>
   Alerts <alerts>
   Badges <badges>
   Breadcrumbs <breadcrumbs>
   Cards <cards>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
